'use client'

import React, { useCallback, useEffect, useState } from 'react';
import { Tag, Button } from 'antd';
import { RightOutlined, PlusOutlined, LeftOutlined } from '@ant-design/icons';
import Image from 'next/image';
import dayjs from 'dayjs';
import { Link } from '../../../navigation';
import { i18nText } from '../../../i18nKeys';
import { getDuration, getPrice } from '../../../utils/expert';
import {PublicUser, Session} from '../../../types/sessions';
import { AUTH_TOKEN_KEY, AUTH_USER } from '../../../constants/common';
import { getSessionDetails } from '../../../actions/profile';
import { useLocalStorage } from '../../../hooks/useLocalStorage';
import { Loader } from '../../view/Loader';

type SessionDetailsProps = {
    locale: string;
    sessionId: number;
    goBack: () => void;
    activeTab: number;
};

export const SessionDetails = ({ sessionId, locale, goBack, activeTab }: SessionDetailsProps) => {
    const [jwt] = useLocalStorage(AUTH_TOKEN_KEY, '');
    const [userId] = useLocalStorage(AUTH_USER, '');
    const [loading, setLoading] = useState<boolean>(false);
    const [errorData, setErrorData] = useState<any>();
    const [session, setSession] = useState<Session>();

    console.log('activeTab', activeTab);

    const fetchData = useCallback(() => {
        setLoading(true);
        setErrorData(undefined);
        setSession(undefined);

        getSessionDetails(locale, jwt, sessionId)
            .then(({ data }) => {
                console.log(data);
                setSession(data);
            })
            .catch((err) => {
                setErrorData(err);
            })
            .finally(() => {
                setLoading(false);
            })
    }, []);

    useEffect(() => {
        fetchData();
    }, [sessionId]);

    const startDate = session?.scheduledStartAtUtc ? dayjs(session?.scheduledStartAtUtc).locale(locale) : null;
    const endDate = session?.scheduledEndAtUtc ? dayjs(session?.scheduledEndAtUtc).locale(locale) : null;
    const today = startDate ? dayjs().format('YYYY-MM-DD') === startDate.format('YYYY-MM-DD') : false;

    const CoachCard = (coach?: PublicUser) => coach ? (
        <div className="card-detail__expert">
            <div className="card-detail__portrait">
                <Image src={coach?.faceImageUrl || '/images/person.png'} width={140} height={140} alt="" />
            </div>
            <div className="card-detail__inner">
                <Link href={`/experts/${coach?.id}` as any} target="_blank">
                    <div className="card-detail__name">{`${coach?.name} ${coach?.surname || ''}`}</div>
                </Link>
                {/* <div className="card-detail__info">
                    <div className="card-profile__subtitle">{coach?.specialityDesc}</div>
                    <div className="card-detail__lang">
                        {coach?.coachLanguages?.map((lang) => (
                            <Tag key={lang} className="skills__list__item">{lang}</Tag>
                        ))}
                    </div>
                </div> */}
                <div className="card-detail__cost">
                    {getPrice(session?.cost)} <span>/ {getDuration(locale, session?.totalDuration)}</span>
                </div>
                <div className={`card-detail__date${today ? ' chosen': ''}${activeTab === 2 ? ' history' : ''}`}>
                    {today
                        ? `${i18nText('today', locale)} ${startDate?.format('HH:mm')} - ${endDate?.format('HH:mm')}`
                        : `${startDate?.format('D MMMM')} ${startDate?.format('HH:mm')} - ${endDate?.format('HH:mm')}`}
                </div>
                <div className="card-detail__skills">
                    <div className="skills__list">
                        {session?.themesTags?.slice(0, 2).map((skill) => <Tag key={skill?.id} className="skills__list__item">{skill?.name}</Tag>)}
                        {session?.themesTags?.length > 2
                            ? (
                                <Tag className="skills__list__more">
                                    <Link href={`/experts/${coach?.id}` as any} target="_blank">
                                        {`+${session?.themesTags?.length - 2}`}
                                    </Link>
                                </Tag>
                            ) : null }
                    </div>
                </div>
                {/* <div className="card-profile__desc">{coach?.description}</div> */}
                <Link href={`/experts/${coach?.id}` as any} target="_blank" className="card-detail__more">
                    {i18nText('details', locale)}
                    <RightOutlined style={{ fontSize: '10px', padding: '0 7px' }}/>
                </Link>
            </div>
        </div>
    ) : null;

    const StudentCard = (student?: PublicUser | null) => student ? (
        <div className="card-detail__expert">
            <div className="card-detail__portrait">
                <Image src={student?.faceImageUrl || '/images/person.png'} width={140} height={140} alt="" />
            </div>
            <div className="card-detail__inner">
                <div className="card-detail__name">{`${student?.name} ${student?.surname || ''}`}</div>
                <div className={`card-detail__date${today ? ' chosen': ''}${activeTab === 2 ? ' history' : ''}`}>
                    {today
                        ? `${i18nText('today', locale)} ${startDate?.format('HH:mm')} - ${endDate?.format('HH:mm')}`
                        : `${startDate?.format('D MMMM')} ${startDate?.format('HH:mm')} - ${endDate?.format('HH:mm')}`}
                </div>
                <div className="card-detail__skills">
                    <div className="skills__list">
                        <Tag className="skills__list__item">{session?.themesTagName}</Tag>
                    </div>
                </div>
                {/* <div className="card-profile__desc">{student?.description}</div> */}
            </div>
        </div>
    ) : null;

    const client = session?.clients?.length ? session?.clients[0] : null;
    const Current = +userId !== client?.id ? StudentCard(client) : CoachCard(session?.coach);

    return (
        <Loader
            isLoading={loading}
            errorData={errorData}
            refresh={fetchData}
        >
            <div className="card-detail">
                <div>
                    <Button
                        className="card-detail__back"
                        type="link"
                        icon={<LeftOutlined />}
                        onClick={goBack}
                    >
                        Back
                    </Button>
                </div>
                {Current}
                {(activeTab === 0 || activeTab === 1) && (
                    <div className="card-detail__actions">
                        {activeTab === 0 ? (
                            <>
                                <Button className="card-detail__apply">Start Session</Button>
                                <Button className="card-detail__decline">Decline Session</Button>
                            </>
                        ) : (
                            <>
                                <Button className="card-detail__apply">Confirm Session</Button>
                                <Button className="card-detail__decline">Decline Session</Button>
                            </>
                        )}
                    </div>
                )}
                {activeTab !== 1 && (
                    <>
                        {activeTab === 2 && (
                            <>
                                <div className="card-detail__name">Course Info</div>
                                <div className="card-detail__inner">
                                    {/* <div className="card-detail__info">
                                        <div className="card-profile__subtitle">{current?.specialityDesc}</div>
                                        <div className="card-detail__lang">
                                            {current?.coachLanguages?.map((lang) => (
                                                <Tag key={lang} className="skills__list__item">{lang}</Tag>
                                            ))}
                                        </div>
                                    </div> */}
                                    <div className="card-detail__cost">
                                        {getPrice(session?.cost)} <span>/ {getDuration(locale, session?.totalDuration)}</span>
                                    </div>
                                    <div className="card-detail__skills">
                                        <div className="skills__list">
                                            {session?.themesTags?.slice(0, 2).map((skill) => <Tag key={skill?.id} className="skills__list__item">{skill?.name}</Tag>)}
                                            {session?.themesTags?.length > 2
                                                ? (
                                                    <Tag className="skills__list__more">
                                                        {`+${session?.themesTags?.length - 2}`}
                                                    </Tag>
                                                ) : null }
                                        </div>
                                    </div>
                                    {/* <div className="card-profile__desc">{current?.description}</div> */}
                                </div>
                            </>
                        )}
                        <div className="card-detail__comments">
                            <div className="card-detail__comments_header">
                                <div className="card-detail__comments_title">
                                    My Comments
                                </div>
                                {activeTab === 0 && (
                                    <Button
                                        className="card-detail__comments_add"
                                        type="link"
                                        iconPosition="end"
                                        icon={<PlusOutlined style={{ fontSize: 18 }} />}
                                    >
                                        Add new
                                    </Button>
                                )}
                            </div>
                            <div className="card-detail__comments_item">
                                Sed tincidunt finibus eros nec feugiat. Nulla facilisi. Nunc maximus magna et egestas tincidunt. Integer lobortis laoreet neque at sodales. Aenean eget risus pharetra, efficitur dolor ut, commodo lacus. Sed vitae nunc odio. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis et velit et dolor rutrum euismod a pretium est.
                            </div>
                            <div className="card-detail__comments_title">
                                Coach Comments
                            </div>
                            <div className="card-detail__comments_item">
                                Sed tincidunt finibus eros nec feugiat. Nulla facilisi. Nunc maximus magna et egestas tincidunt. Integer lobortis laoreet neque at sodales. Aenean eget risus pharetra, efficitur dolor ut, commodo lacus. Sed vitae nunc odio. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis et velit et dolor rutrum euismod a pretium est.
                            </div>
                        </div>
                    </>
                )}
            </div>
        </Loader>
    );
};
